@@ -1,7 +1,7 @@
 /*
  * Seahorse
  *
- * Copyright (C) 2004-2005 Nate Nielsen
+ * Copyright (C) 2004-2005 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,6 @@
 #include <sys/stat.h>
 #include <sys/un.h>
 
-#include <paths.h>
 #include <stddef.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -121,8 +120,8 @@ seahorse_agent_io_socket ()
     
     g_assert (g_socket == -1);
 
-    /* We build put the socket in a directory called ~/.gnome2/seahorse-XXXXXX */
-    t = gnome_util_home_file (SOCKET_DIR);
+    /* We build put the socket in a directory called /tmp/seahorse-XXXXXX */
+    t = g_build_filename (g_get_tmp_dir (), SOCKET_DIR, NULL);
     strncpy (g_socket_name, t, KL (g_socket_name));
     g_free (t);
 
