@@ -2,7 +2,7 @@
  * Seahorse
  *
  * Copyright (C) 2003 Jacob Perkins
- * Copyright (C) 2005, 2006 Nate Nielsen
+ * Copyright (C) 2005, 2006 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1067,7 +1067,7 @@ seahorse_context_discover_keys (SeahorseContext *sctx, GQuark ktype,
     }
     
     /* Start a discover process on all todiscover */
-    if (todiscover) {
+    if (seahorse_gconf_get_boolean (AUTORETRIEVE_KEY) && todiscover) {
         op = seahorse_context_retrieve_keys (sctx, ktype, todiscover, NULL);
 
         /* Add unknown keys for all these */
