@@ -1,7 +1,7 @@
 /*
  * Seahorse
  *
- * Copyright (C) 2003 Nate Nielsen
+ * Copyright (C) 2003 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,9 +22,12 @@
 #include <sys/param.h>
 #include <sys/wait.h>
 #include <sys/file.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <gpgme.h>
 #include <string.h>
 #include <errno.h>
+#include <fcntl.h>
 
 #include "seahorse-gpgmex.h"
 #include "seahorse-util.h"
