@@ -40,6 +40,7 @@ enum {
     PROP_ITEM_ID,
     PROP_ITEM_INFO,
     PROP_ITEM_ATTRIBUTES,
+    PROP_ITEM_ACL,
     PROP_DISPLAY_NAME,
     PROP_DISPLAY_ID,
     PROP_SIMPLE_NAME,
@@ -208,8 +209,8 @@ calc_network_item_markup (SeahorseGKeyringItem *git)
                                object ? object : "");
     }
     
-    ret = g_strdup_printf ("%s<span foreground='#555555' size='small' rise='0'>%s</span>",
-                           display, uri ? uri : "");
+    ret = g_markup_printf_escaped ("%s<span foreground='#555555' size='small' rise='0'>%s</span>",
+                                   display, uri ? uri : "");
     g_free (display);
     g_free (uri);
     
@@ -333,6 +334,9 @@ seahorse_gkeyring_item_get_property (GObject *object, guint prop_id,
     case PROP_ITEM_ATTRIBUTES:
         g_value_set_pointer (value, git->attributes);
         break;
+    case PROP_ITEM_ACL:
+    	g_value_set_pointer (value, git->acl);
+    	break;
     case PROP_DISPLAY_NAME:
         g_value_take_string (value, seahorse_gkeyring_item_get_name (skey, 0));
         break;
@@ -406,6 +410,13 @@ seahorse_gkeyring_item_set_property (GObject *object, guint prop_id, const GValu
             changed_key (git);
         }
         break;
+    case PROP_ITEM_ACL:
+        if (git->acl != g_value_get_pointer (value)) {
+            gnome_keyring_acl_free (git->acl);
+            git->acl = g_value_get_pointer (value);
+            changed_key (git);
+        }
+        break;
     }
 }
 
@@ -422,6 +433,9 @@ seahorse_gkeyring_item_object_finalize (GObject *gobject)
         gnome_keyring_attribute_list_free (git->attributes);
     git->attributes = NULL;
     
+    gnome_keyring_acl_free (git->acl);
+    git->acl = NULL;
+    
     G_OBJECT_CLASS (seahorse_gkeyring_item_parent_class)->finalize (gobject);
 }
 
@@ -458,6 +472,10 @@ seahorse_gkeyring_item_class_init (SeahorseGKeyringItemClass *klass)
         g_param_spec_pointer ("item-attributes", "Item Attributes", "GNOME Keyring Item Attributes",
                               G_PARAM_READWRITE));
 
+    g_object_class_install_property (gobject_class, PROP_ITEM_ACL,
+        g_param_spec_pointer ("item-acl", "Item ACL", "GNOME Keyring Item ACL",
+                              G_PARAM_READWRITE));
+
     g_object_class_install_property (gobject_class, PROP_DISPLAY_NAME,
         g_param_spec_string ("display-name", "Display Name", "User Displayable name for this key",
                              "", G_PARAM_READABLE));
@@ -502,12 +520,13 @@ seahorse_gkeyring_item_class_init (SeahorseGKeyringItemClass *klass)
 
 SeahorseGKeyringItem* 
 seahorse_gkeyring_item_new (SeahorseKeySource *sksrc, guint32 item_id, 
-                            GnomeKeyringItemInfo *info, GnomeKeyringAttributeList *attributes)
+                            GnomeKeyringItemInfo *info, GnomeKeyringAttributeList *attributes, 
+                            GList *acl)
 {
     SeahorseGKeyringItem *git;
     git = g_object_new (SEAHORSE_TYPE_GKEYRING_ITEM, "key-source", sksrc, 
                         "item-id", item_id, "item-info", info, 
-                        "item-attributes", attributes, NULL);
+                        "item-attributes", attributes, "item-acl", acl, NULL);
     
     /* We don't care about this floating business */
     g_object_ref (GTK_OBJECT (git));
@@ -554,10 +573,12 @@ seahorse_gkeyring_item_get_use (SeahorseGKeyringItem *git)
     if (git->attributes) {
         val = seahorse_gkeyring_item_get_attribute (git, "seahorse-key-type");
         if (val) {
+			if (strcmp (val, SKEY_PGP_STR) == 0)
+                return SEAHORSE_GKEYRING_USE_PGP;
+#ifdef WITH_SSH
             if (strcmp (val, SKEY_SSH_STR) == 0)
                 return SEAHORSE_GKEYRING_USE_SSH;
-            else if (strcmp (val, SKEY_PGP_STR) == 0)
-                return SEAHORSE_GKEYRING_USE_PGP;
+#endif
         }
     }
     
@@ -574,3 +595,4 @@ seahorse_gkeyring_item_get_cannonical (guint32 item_id)
     buf[BUF_LEN - 1] = 0;
     return g_quark_from_string (buf);
 }
+
